local _, Addon = ...
local Ability = Addon:NewModule('Ability')
local Battle = Addon.BattlePets

local MODIFIER_ICON = 'Interface\\PetBattles\\BattleBar-AbilityBadge-'
local Journal = C_PetJournal


--[[ Update ]]--

function Ability:Update(pet, target)
	local i = self:GetID()
	local id, _, icon = pet:GetAbilityInfo(i)
	local type = pet:GetAbilityType(i)

	local modifier, usable, level, cooldown, onCooldown	
	if id then
		modifier = 1
		usable, cooldown = pet:GetAbilityState(i)
		onCooldown = cooldown and cooldown > 0
		usable = usable and not onCooldown
	else 
		id, level = Ability.FindID(self, pet)
		name, icon = Journal.GetPetAbilityInfo(id)
		modifier = 1
	end
	
	self:SetScript('OnEnter', Ability.OnEnter)
	self:SetScript('OnLeave', Ability.OnLeave)
	self.id, self.reqLevel = id, level
	self.pet = pet
	
	Ability.UpdateIcon(self, icon, usable, level)
	Ability.UpdateCooldown(self, onCooldown, cooldown)
	Ability.UpdateModifier(self, modifier)
end

function Ability:UpdateIcon(icon, usable, locked)
	local color = usable and 1 or .5
	self.Icon:SetTexture(icon)
	self.Icon:SetDesaturated(not usable)
	self.Icon:SetVertexColor(color, color, color)
	self.Lock:SetShown(locked)
end

function Ability:UpdateCooldown(onCooldown, cooldown)
	self.Cooldown:SetText(cooldown or "")
	self.CooldownShadow:SetShown(onCooldown)
	self.Cooldown:SetShown(onCooldown)
end

function Ability:UpdateModifier(modifier)
	self.BetterIcon:SetTexture(MODIFIER_ICON .. (modifier > 1 and 'Strong' or 'Weak'))
	self.BetterIcon:SetShown(modifier ~= 1)
end


--[[ Tooltip ]]--

function Ability:OnEnter()
	local pet = self.pet
	local level = self.reqLevel and PET_ABILITY_REQUIRES_LEVEL:format(self.reqLevel)
	
	PetBattleAbilityTooltip_SetAbilityByID(pet.owner, pet.index, self.id, level)
	PetBattleAbilityTooltip_Show('TOP', self, 'BOTTOM')
end

function Ability:OnLeave()
	PetBattlePrimaryAbilityTooltip:Hide()
end


--[[ API ]]--

function Ability:FindID(pet)
	local i = self:GetID()
	local abilities, levels = Journal.GetPetAbilityList(pet:GetSpecie())
	return abilities[i], levels[i]
end