local _, Addon = ...
local Battle = C_PetBattles
local Pets = Addon:NewModule('BattlePets')
local TYPE_ICONS = 'Interface/PetBattles/PetIcon-'


--[[ Static ]]--

function Pets:Get(owner, index)
	local pet = {
		owner = owner,
		index = index,
	}
	
	return setmetatable(pet, self)
end

function Pets:GetCurrent(owner)
	local index = Battle.GetActivePet(owner)
	return self:Get(owner, index)
end

function Pets:GetNum(owner)
	return Battle.GetNumPets(owner)
end


--[[ Display ]]--

function Pets:GetDisplayInfo()
	local name, specieName = self:GetDisplayNames()
	return name, specieName,
		self:GetIcon(),
		self:GetTypeIcon(),
		self:GetModel()
end

function Pets:GetDisplayNames()
	local name, specieName = self:GetName()
	return name, specieName ~= name and specieName or ''
end

function Pets:GetTypeIcon()
	return TYPE_ICONS .. PET_TYPE_SUFFIX[self:GetType()]
end

function Pets:GetStats()
	return self:GetHealth(),
		self:GetMaxHealth(),
		self:GetPower(),
		self:GetSpeed(),
		self:GetLevel()
end

function Pets:Swap()
	Battle.ChangePet(self.index)
end

function Pets:CanSwap()
	return Battle.CanPetSwapIn(self.index)
end

function Pets:GetAbilityType(i)
	return select(7, self:GetAbilityInfo(i))
end


--[[ Basic ]]--

function Pets:Exists()
	return self:GetNum(self.owner) >= self.index
end

function Pets:IsAlive()
	return self:GetHealth() > 0
end

function Pets:GetType()
	return self:GetPetType()
end

function Pets:GetSpecie()
	return self:GetPetSpeciesID()
end

function Pets:GetModel()
	return self:GetDisplayID()
end

function Pets:__index(key)
	return Pets[key] or function(self, ...)
		assert(Battle[key], key .. ' not found.')
		return Battle[key](self.owner, self.index, ...)
	end
end